==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PlatformConditionEvaluatorPlatformOperatingSystemVersion.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionOperatingSystemVersionMatchType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformConditionEvaluatorPlatformOperatingSystemVersion
 */
@JsonPropertyOrder({ PlatformConditionEvaluatorPlatformOperatingSystemVersion.JSON_PROPERTY_MATCH_TYPE,
        PlatformConditionEvaluatorPlatformOperatingSystemVersion.JSON_PROPERTY_VALUE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PlatformConditionEvaluatorPlatformOperatingSystemVersion implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MATCH_TYPE = "matchType";
    private PlatformConditionOperatingSystemVersionMatchType matchType;

    public static final String JSON_PROPERTY_VALUE = "value";
    private String value;

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion() {
    }

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion matchType(
            PlatformConditionOperatingSystemVersionMatchType matchType) {

        this.matchType = matchType;
        return this;
    }

    /**
     * Get matchType
     *
     * @return matchType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MATCH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformConditionOperatingSystemVersionMatchType getMatchType() {
        return matchType;
    }

    @JsonProperty(JSON_PROPERTY_MATCH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMatchType(PlatformConditionOperatingSystemVersionMatchType matchType) {
        this.matchType = matchType;
    }

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion value(String value) {

        this.value = value;
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(String value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformConditionEvaluatorPlatformOperatingSystemVersion platformConditionEvaluatorPlatformOperatingSystemVersion = (PlatformConditionEvaluatorPlatformOperatingSystemVersion) o;
        return Objects.equals(this.matchType, platformConditionEvaluatorPlatformOperatingSystemVersion.matchType)
                && Objects.equals(this.value, platformConditionEvaluatorPlatformOperatingSystemVersion.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(matchType, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformConditionEvaluatorPlatformOperatingSystemVersion {\n");
        sb.append("    matchType: ").append(toIndentedString(matchType)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PlatformConditionEvaluatorPlatformOperatingSystemVersion.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionOperatingSystemVersionMatchType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformConditionEvaluatorPlatformOperatingSystemVersion
 */
@JsonPropertyOrder({ PlatformConditionEvaluatorPlatformOperatingSystemVersion.JSON_PROPERTY_MATCH_TYPE,
        PlatformConditionEvaluatorPlatformOperatingSystemVersion.JSON_PROPERTY_VALUE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PlatformConditionEvaluatorPlatformOperatingSystemVersion implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MATCH_TYPE = "matchType";
    private PlatformConditionOperatingSystemVersionMatchType matchType;

    public static final String JSON_PROPERTY_VALUE = "value";
    private String value;

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion() {
    }

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion matchType(
            PlatformConditionOperatingSystemVersionMatchType matchType) {

        this.matchType = matchType;
        return this;
    }

    /**
     * Get matchType
     *
     * @return matchType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MATCH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformConditionOperatingSystemVersionMatchType getMatchType() {
        return matchType;
    }

    @JsonProperty(JSON_PROPERTY_MATCH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMatchType(PlatformConditionOperatingSystemVersionMatchType matchType) {
        this.matchType = matchType;
    }

    public PlatformConditionEvaluatorPlatformOperatingSystemVersion value(String value) {

        this.value = value;
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(String value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformConditionEvaluatorPlatformOperatingSystemVersion platformConditionEvaluatorPlatformOperatingSystemVersion = (PlatformConditionEvaluatorPlatformOperatingSystemVersion) o;
        return Objects.equals(this.matchType, platformConditionEvaluatorPlatformOperatingSystemVersion.matchType)
                && Objects.equals(this.value, platformConditionEvaluatorPlatformOperatingSystemVersion.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(matchType, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformConditionEvaluatorPlatformOperatingSystemVersion {\n");
        sb.append("    matchType: ").append(toIndentedString(matchType)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
